@@ -1,5 +1,5 @@
 #
-# $Id: IPv4.pm,v 1.3.2.13 2006/11/18 12:51:16 gomor Exp $
+# $Id: IPv4.pm,v 1.3.2.14 2006/12/16 15:28:05 gomor Exp $
 #
 package Net::Packet::IPv4;
 use strict;
@@ -12,6 +12,7 @@ use Carp;
 use Net::Packet::Env qw($Env);
 use Net::Packet::Utils qw(getRandom16bitsInt inetAton inetNtoa inetChecksum);
 use Net::Packet::Consts qw(:ipv4 :layer);
+require Bit::Vector;
 
 our @AS = qw(
    id
@@ -69,20 +70,25 @@ sub new {
 sub pack {
    my $self = shift;
 
-   # Thank you Stephanie Wehner
-   my $hlenVer  = ($self->[$__hlen] & 0x0f)|(($self->[$__version] << 4) & 0xf0);
-   my $flags    = $self->[$__flags];
-   my $offset   = $self->[$__offset];
+   # Here, we pack in this order: version, hlen (4 bits each)
+   my $version = Bit::Vector->new_Dec(4, $self->[$__version]);
+   my $hlen    = Bit::Vector->new_Dec(4, $self->[$__hlen]);
+   my $v8      = $version->Concat_List($hlen);
+
+   # Here, we pack in this order: flags (3 bits), offset (13 bits)
+   my $flags  = Bit::Vector->new_Dec(3,  $self->[$__flags]);
+   my $offset = Bit::Vector->new_Dec(13, $self->[$__offset]);
+   my $v16    = $flags->Concat_List($offset);
 
    my $len = ($self->[$__noFixLen] ? _fixLenOther($self->[$__length])
                                    : _fixLen($self->[$__length]));
 
    $self->[$__raw] = $self->SUPER::pack('CCa*nnCCna4a4',
-      $hlenVer,
+      $v8->to_Dec,
       $self->[$__tos],
       $len,
       $self->[$__id],
-      $flags << 13 | $offset,
+      $v16->to_Dec,
       $self->[$__ttl],
       $self->[$__protocol],
       $self->[$__checksum],
@@ -103,17 +109,22 @@ sub pack {
 sub unpack {
    my $self = shift;
 
-   my ($verHlen, $tos, $len, $id, $flags, $ttl, $proto, $cksum, $src, $dst,
-      $payload) = $self->SUPER::unpack('CCnnnCCna4a4 a*', $self->[$__raw])
+   my ($verHlen, $tos, $len, $id, $flagsOffset, $ttl, $proto, $cksum, $src,
+      $dst, $payload) = $self->SUPER::unpack('CCnnnCCna4a4 a*', $self->[$__raw])
          or return undef;
 
-   $self->[$__version] = ($verHlen & 0xf0) >> 4;
-   $self->[$__hlen] = $verHlen & 0x0f;
+   my $v8  = Bit::Vector->new_Dec(8,  $verHlen);
+   my $v16 = Bit::Vector->new_Dec(16, $flagsOffset);
+
+   # Here, we unpack in this order: hlen, version (4 bits each)
+   $self->[$__hlen] = $v8->Chunk_Read(4, 0);
+   $self->[$__version] = $v8->Chunk_Read(4, 4);
    $self->[$__tos] = $tos;
    $self->[$__length] = $len;
    $self->[$__id] = $id;
-   $self->[$__flags] = $flags >> 13;
-   $self->[$__offset] = $flags & 0x1FFF;
+   # Here, we unpack in this order: offset (13 bits), flags (3 bits)
+   $self->[$__offset] = $v16->Chunk_Read(13,  0);
+   $self->[$__flags] = $v16->Chunk_Read( 3, 13);
    $self->[$__ttl] = $ttl;
    $self->[$__protocol] = $proto;
    $self->[$__checksum] = $cksum;
